@@ -49,7 +49,7 @@ test<-try({
   remove(mask,blau,classes)
 gc(verbose=FALSE)
 },silent=TRUE)
-if(class(test)=="try-error")cat(paste0(file,": ",attr(test,"condition"),"\n"))
+if(inherits(test,"try-error"))cat(paste0(file,": ",attr(test,"condition"),"\n"))
 else(cat(paste0(file," OK\n")))
 
 }
