@@ -93,7 +93,7 @@ compute.distance2border.nospots.file<-function(file,N,color, output)
     save(d2b,file=paste(dir,"/",file,".Rdata",sep=""))
     gc(verbose=FALSE)
   },silent=TRUE)
-  if(class(test)=="try-error")cat(paste0(file,": ",attr(test,"condition"),"\n"))
+  if(inherits(test,"try-error"))cat(paste0(file,": ",attr(test,"condition"),"\n"))
   else(cat(paste0(file," OK\n")))
 }
 compute.distance2border.spots.file<-function(file,dir,N,color, output)  
